@@ -206,18 +206,42 @@ public class ApplicationWorkbenchAdvisor extends WorkbenchAdvisor {
 	public void initialize(final IWorkbenchConfigurer configurer) {
 		super.initialize(configurer);
 
+		// このメソッド内で worked ４回
+		// Initializer.initialize() 内で３回
+		// Eclipse内で１回
+		SplashProgressMonitor.beginTask("", 4+3+1);
+
+		// デフォルトコンソールの作成
+		SplashProgressMonitor.subTask("Creating Default Console");
+
 		createDefaultConsole();
 
+		SplashProgressMonitor.worked(1);
+
+		// ヒープサイズのチェック
+		SplashProgressMonitor.subTask("Checking Heap Size");
+
 		if (checkHeapAndModifyJavieIni()) {
 			configurer.getWorkbench().restart();
 			return;
 		}
 
+		SplashProgressMonitor.worked(1);
+
+
+		// その他の初期化
+		SplashProgressMonitor.subTask("");
+
 		configurer.setSaveAndRestore(true);
 
 		IOperationHistory history = configurer.getWorkbench().getOperationSupport().getOperationHistory();
 		history.addOperationApprover(new LinearUndoEnforcer());
 
+		SplashProgressMonitor.worked(1);
+
+
+		// OpenGLの初期化
+		SplashProgressMonitor.subTask("Initializing OpenGL");
 
 		String os = Platform.getOS();
 		boolean win32 = os.equals(Platform.OS_WIN32);
@@ -256,6 +280,8 @@ public class ApplicationWorkbenchAdvisor extends WorkbenchAdvisor {
 			});
 		}
 
+		SplashProgressMonitor.worked(1);
+
 		Initializer.initialize();
 	}
 
