@@ -58,6 +58,7 @@ import ch.kuramo.javie.app.project.ProjectEvent;
 import ch.kuramo.javie.app.project.ProjectEventHub;
 import ch.kuramo.javie.app.project.ProjectListener;
 import ch.kuramo.javie.core.CompositionItem;
+import ch.kuramo.javie.core.FrameDuration;
 import ch.kuramo.javie.core.MediaInput;
 import ch.kuramo.javie.core.MediaItem;
 import ch.kuramo.javie.core.Project;
@@ -361,8 +362,12 @@ public class MediaPlayer extends Composite implements PlayerThreadListener, Play
 		_duration = input.getDuration();
 
 		if (_duration != null) {
-			if (input.isVideoAvailable() && input.getVideoFrameDuration().timeValue > 0) {
-				_frameDuration = input.getVideoFrameDuration();
+			if (input.isVideoAvailable()) {
+				if (input.getVideoFrameDuration().timeValue > 0) {
+					_frameDuration = input.getVideoFrameDuration();
+				} else {
+					_frameDuration = FrameDuration.FPS_59_94;
+				}
 			} else {
 				// TODO これだとデュレーションが12時間25分以上になると問題が発生するはず。
 				_frameDuration = new Time(1, 48000);
