@@ -278,7 +278,7 @@ public class VideoCanvas extends Thread implements GLEventListener {
 
 				e.display.asyncExec(new Runnable() {
 					public void run() {
-						if (!_scrolled.isDisposed()) {
+						if (_glCanvasRecord != null) {
 							_glCanvasRecord.awtFrame.repaint();
 						}
 					}
