@@ -81,6 +81,7 @@ import org.eclipse.ui.part.ViewPart;
 import ch.kuramo.javie.app.ColorUtil;
 import ch.kuramo.javie.app.DropTargetEnhancement;
 import ch.kuramo.javie.app.UIUtil;
+import ch.kuramo.javie.app.actions.MediaOptionsDialogAction;
 import ch.kuramo.javie.app.actions.NewCompositionAction;
 import ch.kuramo.javie.app.actions.NewFileItemsAction;
 import ch.kuramo.javie.app.actions.NewFolderAction;
@@ -251,6 +252,7 @@ public class ProjectView extends ViewPart {
 		menuMgr.add(inputMenu);
 		menuMgr.add(new Separator());
 		menuMgr.add(new RenameItemAction(window, _treeViewer));
+		menuMgr.add(new MediaOptionsDialogAction(window, _treeViewer));
 		menuMgr.add(deleteAction);
 		menuMgr.add(new GroupMarker(IWorkbenchActionConstants.MB_ADDITIONS));
 
@@ -517,8 +519,8 @@ public class ProjectView extends ViewPart {
 			if (comp instanceof LayerComposition) {
 				LayerComposition layerComp = (LayerComposition) comp;
 				for (Layer layer : layerComp.getLayers()) {
-					if (layer instanceof ItemLayer) {
-						usedItems.add(((ItemLayer) layer).getItem());
+					if (layer instanceof ItemLayer<?>) {
+						usedItems.add(((ItemLayer<?>) layer).getItem());
 					}
 				}
 			}
