@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -49,6 +49,7 @@ import javassist.bytecode.SignatureAttribute.NestedClassType;
 import org.scannotation.AnnotationDB;
 
 import ch.kuramo.javie.api.annotations.Property;
+import ch.kuramo.javie.api.annotations.Effect.Categories;
 import ch.kuramo.javie.core.Effect;
 import ch.kuramo.javie.core.EffectConverter;
 import ch.kuramo.javie.core.EffectDescriptor;
@@ -76,6 +77,9 @@ public class EffectRegistryImpl implements EffectRegistry {
 			return;
 		}
 
+		final boolean macosx = System.getProperty("os.name")
+				.toLowerCase().replaceAll("\\s+", "").contains("macosx");
+
 		List<EffectDescriptor> descriptors = Util.newList();
 
 		ClassPool pool = new ClassPool();
@@ -100,6 +104,11 @@ public class EffectRegistryImpl implements EffectRegistry {
 					ch.kuramo.javie.api.annotations.Effect effectAnno
 							= (ch.kuramo.javie.api.annotations.Effect) anno;
 
+					// FIXME 特定の環境でのみ動作するエフェクトであることを示すフラグ等が必要
+					if (effectAnno.category().equals(Categories.QUARTZ_COMPOSER_CONTROLS) && !macosx) {
+						break;
+					}
+
 					String type = effectAnno.id();
 					if (type.equals("")) {
 						type = className;
