@@ -375,14 +375,17 @@ public class ShaderRegistryImpl implements ShaderRegistry, IShaderRegistry {
 			int[] length = new int[1];
 			gl.glGetProgramiv(program, GL2.GL_INFO_LOG_LENGTH, length, 0);
 
-			byte[] infoLogBuf = new byte[length[0]];
-			gl.glGetProgramInfoLog(program, length[0], length, 0, infoLogBuf, 0);
-
 			String infoLog;
-			try {
-				infoLog = new String(infoLogBuf, 0, length[0], "ISO-8859-1");
-			} catch (UnsupportedEncodingException e) {
-				infoLog = new String(infoLogBuf, 0, length[0]);
+			if (length[0] > 0) {
+				byte[] infoLogBuf = new byte[length[0]];
+				gl.glGetProgramInfoLog(program, length[0], length, 0, infoLogBuf, 0);
+				try {
+					infoLog = new String(infoLogBuf, 0, length[0], "ISO-8859-1");
+				} catch (UnsupportedEncodingException e) {
+					infoLog = new String(infoLogBuf, 0, length[0]);
+				}
+			} else {
+				infoLog = "(no info log)";
 			}
 			throw new ShaderRegistryException(entry.name, "link failed: " + infoLog);
 
