@@ -101,8 +101,7 @@ public class VideoEffectPipelineImpl implements VideoEffectPipeline {
 	}
 
 
-	private class VideoEffectContextImpl
-			extends AbstractEffectContext implements IVideoEffectContext {
+	class VideoEffectContextImpl extends AbstractEffectContext implements IVideoEffectContext {
 
 		private List<VideoEffect> effects;
 
@@ -114,6 +113,8 @@ public class VideoEffectPipelineImpl implements VideoEffectPipeline {
 
 		private boolean gettingBounds;
 
+		private QCIntegrationSupportImpl qcisImpl;
+
 
 		private VideoEffectContextImpl(
 				MediaLayer layer, List<VideoEffect> effects,
@@ -228,6 +229,13 @@ public class VideoEffectPipelineImpl implements VideoEffectPipeline {
 			return currentEffect.getName();
 		}
 
+		QCIntegrationSupportImpl getQCISImpl() {
+			if (qcisImpl == null) {
+				qcisImpl = new QCIntegrationSupportImpl();
+			}
+			return qcisImpl;
+		}
+
 	}
 
 }
