@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010 Yoshikazu Kuramochi
+ * Copyright (c) 2010,2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -37,7 +37,9 @@ import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.AudioMode.DataType;
 import ch.kuramo.javie.core.Composition;
+import ch.kuramo.javie.core.annotations.ProjectElement;
 
+@ProjectElement("macOSXQTMovieOutput")
 public class MacOSXQTMovieOutput extends PullSourceOutput {
 
 	private static final Logger _logger = LoggerFactory.getLogger(MacOSXQTMovieOutput.class);
@@ -246,10 +248,12 @@ public class MacOSXQTMovieOutput extends PullSourceOutput {
 
 
 	public static class VideoCompressorSettings {
-		private final byte[] settings;
-		public final int depth;
-		public final double frameRate;
-		public final String text;
+		public/*private final*/ byte[] settings;
+		public /*final*/ int depth;
+		public /*final*/ double frameRate;
+		public /*final*/ String text;
+
+		public VideoCompressorSettings() { }
 
 		private VideoCompressorSettings(byte[] settings, int depth, double frameRate, String text) {
 			this.settings = settings;
@@ -283,9 +287,11 @@ public class MacOSXQTMovieOutput extends PullSourceOutput {
 	}
 
 	public static class AudioCompressorSettings {
-		private final byte[] settings;
-		public final double sampleRate;
-		public final String text;
+		public/*private final*/ byte[] settings;
+		public /*final*/ double sampleRate;
+		public /*final*/ String text;
+
+		public AudioCompressorSettings() { }
 
 		private AudioCompressorSettings(byte[] settings, double sampleRate, String text) {
 			this.settings = settings;
@@ -317,7 +323,18 @@ public class MacOSXQTMovieOutput extends PullSourceOutput {
 	}
 
 
-	static { System.loadLibrary("QTMovieOutput"); }
+	public static final boolean AVAILABLE;
+
+	static {
+		boolean available = false;
+		try {
+			System.loadLibrary("QTMovieOutput");
+			available = true;
+		} catch (Throwable t) {
+			//t.printStackTrace();
+		}
+		AVAILABLE = available;
+	}
 
 	private static native int doVideoCompressorSettings(
 			byte[] defaultSettings, double defaultFrameRate, boolean showDialog, Object[] newSettings);
