@@ -93,8 +93,10 @@ public class FTGL {
 		return lib.ftglGetFontCharMapCount(font);
 	}
 
-	public synchronized static int ftglGetFontCharMapList(FTGLfont font) {
-		return lib.ftglGetFontCharMapList(font);
+	public synchronized static int[] ftglGetFontCharMapList(FTGLfont font) {
+		int count = lib.ftglGetFontCharMapCount(font);
+		Pointer p = lib.ftglGetFontCharMapList(font);
+		return p.getIntArray(0, count);
 	}
 
 	public synchronized static float ftglGetFontDescender(FTGLfont font) {
@@ -462,7 +464,7 @@ interface FTGLLib extends Library {
 	 * 
 	 * FT_Encoding *ftglGetFontCharMapList(FTGLfont *font)
 	 */
-	int ftglGetFontCharMapList(FTGLfont font);
+	Pointer ftglGetFontCharMapList(FTGLfont font);
 
 
 	/**
